#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-DcQJ27vQb601JFKFTHYr9t
key:                  haskell-language-server-2.3.0.0-DcQJ27vQb601JFKFTHYr9t
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9f62a8baaf4dfd29f21d36f95fa26fb5
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-DcQJ27vQb601JFKFTHYr9t
depends:
    aeson-pretty-0.8.10-I8RqFE2DLM47pzJHClh0vy
    async-2.2.6-nyFy7OLTowBs5uBnsBun9 base-4.18.2.1
    base16-bytestring-1.0.2.0-2K2NwdE4gW3En3QIR8OMok
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-7w54gJZoXlFHSVL6XBnNdr
    data-default-0.7.1.3-Jbl1GQbSIet3IvhyjwA92u directory-1.3.8.5
    extra-1.7.16-JAT04zRaS227Y2Fu3FxmcZ filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-LPI2jVd4wCZKpUpgRekfaA
    githash-0.1.6.3-4WWxKrZmafb5rkidsD1Vb2
    hie-bios-0.12.0-HWUkTwJZajP4a4QHVjpdFl
    hiedb-0.4.3.0-Bdv1IQtW2IDKXj8HujAunr
    hls-alternate-number-format-plugin-2.3.0.0-HI2009iooxI57BuLj3q61U
    hls-cabal-fmt-plugin-2.3.0.0-5M36tJZRotI4qoimU7y1ib
    hls-cabal-plugin-2.3.0.0-6j9CdLkzcfvBO1EntOJQ4X
    hls-call-hierarchy-plugin-2.3.0.0-2GsZf4RsUTZLxOHguMPw6q
    hls-change-type-signature-plugin-2.3.0.0-1lPCjxxfnmhAxStM3P7rE0
    hls-class-plugin-2.3.0.0-9zVfzmnw8heCMSlKlRBudC
    hls-code-range-plugin-2.3.0.0-7VRyLfieR1k1JFA2hpYcWG
    hls-eval-plugin-2.3.0.0-J3VpXDuZl36LUVCYojyQ4Z
    hls-explicit-fixity-plugin-2.3.0.0-1UwPAffiHsy6gnc0OPxPJ6
    hls-explicit-imports-plugin-2.3.0.0-4KpCl68ie0DJQqHFajcoNW
    hls-explicit-record-fields-plugin-2.3.0.0-8G6RQuIK35l9HocqNgzq2w
    hls-fourmolu-plugin-2.3.0.0-FNStiRApX88IPILQAbFJxh
    hls-gadt-plugin-2.3.0.0-8XD3hONNN0s9noDplJHrDZ
    hls-graph-2.3.0.0-7Wcz5XT6J7K441KLP11qra
    hls-hlint-plugin-2.3.0.0-1y2qXIf9dghDoSnfvMojJh
    hls-module-name-plugin-2.3.0.0-ELmQMxRgVqqLAtvp8ekn8P
    hls-ormolu-plugin-2.3.0.0-57jx5eDiLmZ76rMQcy0TfM
    hls-overloaded-record-dot-plugin-2.3.0.0-AIdJPtw0624EPWCAAbwFPM
    hls-plugin-api-2.3.0.0-5nYoBlahDCdHF771EwbzWf
    hls-pragmas-plugin-2.3.0.0-4qn6fn8dVl6GYoar3U0wVD
    hls-qualify-imported-names-plugin-2.3.0.0-GmaLYatNtyLG6WHUFe6gxw
    hls-refactor-plugin-2.3.0.0-BtO1ci4JJFV792w8tFd5RN
    hls-rename-plugin-2.3.0.0-6xclO3ufbIW6Vx5cPt0m5c
    hls-retrie-plugin-2.3.0.0-7h5UXtXqFUqBLHTPRCiMoR
    hls-splice-plugin-2.3.0.0-4ZwTNukA2yP94BN1ZlhfNI
    hls-stylish-haskell-plugin-2.3.0.0-LKcYS2INEOoGVVKZcPZn1l
    lsp-2.2.0.0-8moaND8Ecu3E4ZkxeL0gCy
    optparse-applicative-0.18.1.0-LHvXpPQWKqi4UK7hRHCcCN
    optparse-simple-0.1.1.4-5yjs1g3GBnF5psJ8cWi6Hr
    prettyprinter-1.7.1-EUg2EVQteTx5yJ2Pr03pBI process-1.6.19.0
    safe-exceptions-0.1.7.4-GwV2s4MboBp24BDWb53lX9
    sqlite-simple-0.4.19.0-7C1VICaoVw2LqkyptSzWFo text-2.0.2
    unordered-containers-0.2.20.1-9qQGbgjzyj0ISlxTMt28N2

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

